@@ -69,7 +69,7 @@ use Coro::AnyEvent ();
 
 use base Exporter::;
 
-our $VERSION = 6.514;
+our $VERSION = 6.54;
 
 our @EXPORT    = (@IO::AIO::EXPORT, qw(aio_wait));
 our @EXPORT_OK = @IO::AIO::EXPORT_OK;
@@ -94,6 +94,11 @@ our $AUTOLOAD;
       $proto =~ s/;//g; # we do not support optional arguments
       $proto =~ s/^(\$*)\$$/$1/ or die "$iosub($proto): unable to remove callback slot from prototype";
 
+      # we add ; to avoid generating "$" which is specialcased to mean named unary function
+      # without this, Coro::AIO::aio_mlockall IO::AIO::MCL_CURRENT | IO::AIO::MCL_FUTURE
+      # is parsed as (Coro::AIO::aio_mlockall IO::AIO::MCL_CURRENT) | IO::AIO::MCL_FUTURE.
+      $proto .= ";";
+
       _register "Coro::AIO::$sub", $proto, \&{$iosub};
    }
 
